==> members-facade-2.0.0-20191008.014844-32-sources.jar: com/bizvane/members/facade/models/po/MbrDistributionRecordPO.java <==
package com.bizvane.members.facade.models.po;

import java.io.Serializable;
import java.util.Date;

public class MbrDistributionRecordPO implements Serializable {
    /**
     * 只读.
    主键id. mbr_distribution_record_id
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "主键id",name = "mbrDistributionRecordId", required = false,example = "")
    private Long mbrDistributionRecordId;

    /**
     * 只读.
    企业id. sys_company_id
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "企业id",name = "sysCompanyId", required = false,example = "")
    private Long sysCompanyId;

    /**
     * 只读.
    品牌id. brand_id
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "品牌id",name = "brandId", required = false,example = "")
    private Long brandId;

    /**
     * 只读.
    分销员手机号(上线). p_phone
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "分销员手机号(上线)",name = "pPhone", required = false,example = "")
    private String pPhone;

    /**
     * 只读.
    分销员姓名. p_name
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "分销员姓名",name = "pName", required = false,example = "")
    private String pName;

    /**
     * 只读.
    分销员membercode. p_member_code
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "分销员membercode",name = "pMemberCode", required = false,example = "")
    private String pMemberCode;

    /**
     * 只读.
    线下会员手机号. c_phone
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "线下会员手机号",name = "cPhone", required = false,example = "")
    private String cPhone;

    /**
     * 只读.
    下线名称. c_name
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "下线名称",name = "cName", required = false,example = "")
    private String cName;

    /**
     * 只读.
    下线member_code. c_member_code
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "下线member_code",name = "cMemberCode", required = false,example = "")
    private String cMemberCode;

    /**
     * 只读.
    订单号. order_no
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "订单号",name = "orderNo", required = false,example = "")
    private String orderNo;

    /**
     * 只读.
    订单金额. trade_amount
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "订单金额",name = "tradeAmount", required = false,example = "")
    private Short tradeAmount;

    /**
     * 只读.
    实付金额. commodity_amount
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "实付金额",name = "commodityAmount", required = false,example = "")
    private Short commodityAmount;

    /**
     * 只读.
    佣金. commission
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "佣金",name = "commission", required = false,example = "")
    private Integer commission;

    /**
     * 只读.
    佣金状态 1待结算 2一结算 3退货. commission_status
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "佣金状态 1待结算 2一结算 3退货",name = "commissionStatus", required = false,example = "")
    private Integer commissionStatus;

    /**
     * 只读.
    消费日期. consume_date
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "消费日期",name = "consumeDate", required = false,example = "")
    private Date consumeDate;

    /**
     * 只读.
    结算日期. deal_date
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "结算日期",name = "dealDate", required = false,example = "")
    private Date dealDate;

    /**
     * 只读.
    佣金规则. regx
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "佣金规则",name = "regx", required = false,example = "")
    private String regx;

    /**
     * 只读.
    数据有效性 1有效 0无效. valid
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "数据有效性 1有效 0无效",name = "valid", required = false,example = "")
    private Boolean valid;

    /**
     * 只读.
    备注. remark
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "备注",name = "remark", required = false,example = "")
    private String remark;

    /**
     * 只读.
    创建人id. create_user_id
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "创建人id",name = "createUserId", required = false,example = "")
    private Long createUserId;

    /**
     * 只读.
    创建人. create_user_name
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "创建人",name = "createUserName", required = false,example = "")
    private String createUserName;

    /**
     * 只读.
    创建日期. create_date
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "创建日期",name = "createDate", required = false,example = "")
    private Date createDate;

    /**
     * 只读.
    修改人id. modified_user_id
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "修改人id",name = "modifiedUserId", required = false,example = "")
    private Long modifiedUserId;

    /**
     * 只读.
    修改人. modified_user_name
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "修改人",name = "modifiedUserName", required = false,example = "")
    private String modifiedUserName;

    /**
     * 只读.
    修改日期. modified_date
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "修改日期",name = "modifiedDate", required = false,example = "")
    private Date modifiedDate;

    /**
     * 只读.
    版本号. version
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "版本号",name = "version", required = false,example = "")
    private Integer version;

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    private static final long serialVersionUID = 1L;

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Long getMbrDistributionRecordId() {
        return mbrDistributionRecordId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setMbrDistributionRecordId(Long mbrDistributionRecordId) {
        this.mbrDistributionRecordId = mbrDistributionRecordId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Long getBrandId() {
        return brandId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public String getpPhone() {
        return pPhone;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setpPhone(String pPhone) {
        this.pPhone = pPhone == null ? null : pPhone.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public String getpName() {
        return pName;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setpName(String pName) {
        this.pName = pName == null ? null : pName.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public String getpMemberCode() {
        return pMemberCode;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setpMemberCode(String pMemberCode) {
        this.pMemberCode = pMemberCode == null ? null : pMemberCode.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public String getcPhone() {
        return cPhone;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setcPhone(String cPhone) {
        this.cPhone = cPhone == null ? null : cPhone.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public String getcName() {
        return cName;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setcName(String cName) {
        this.cName = cName == null ? null : cName.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public String getcMemberCode() {
        return cMemberCode;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setcMemberCode(String cMemberCode) {
        this.cMemberCode = cMemberCode == null ? null : cMemberCode.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public String getOrderNo() {
        return orderNo;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setOrderNo(String orderNo) {
        this.orderNo = orderNo == null ? null : orderNo.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Short getTradeAmount() {
        return tradeAmount;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setTradeAmount(Short tradeAmount) {
        this.tradeAmount = tradeAmount;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Short getCommodityAmount() {
        return commodityAmount;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setCommodityAmount(Short commodityAmount) {
        this.commodityAmount = commodityAmount;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Integer getCommission() {
        return commission;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setCommission(Integer commission) {
        this.commission = commission;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Integer getCommissionStatus() {
        return commissionStatus;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setCommissionStatus(Integer commissionStatus) {
        this.commissionStatus = commissionStatus;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Date getConsumeDate() {
        return consumeDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setConsumeDate(Date consumeDate) {
        this.consumeDate = consumeDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Date getDealDate() {
        return dealDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setDealDate(Date dealDate) {
        this.dealDate = dealDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public String getRegx() {
        return regx;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setRegx(String regx) {
        this.regx = regx == null ? null : regx.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Boolean getValid() {
        return valid;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setValid(Boolean valid) {
        this.valid = valid;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setRemark(String remark) {
        this.remark = remark == null ? null : remark.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Long getCreateUserId() {
        return createUserId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public String getCreateUserName() {
        return createUserName;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName == null ? null : createUserName.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Date getCreateDate() {
        return createDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public String getModifiedUserName() {
        return modifiedUserName;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Date getModifiedDate() {
        return modifiedDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Integer getVersion() {
        return version;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setVersion(Integer version) {
        this.version = version;
    }
}

==> members-facade-20250930-20250911.094123-7-sources.jar: com/bizvane/members/facade/models/po/MbrDistributionRecordPO.java <==
package com.bizvane.members.facade.models.po;

import com.bizvane.members.facade.utils.EncryptCardNo;
import com.bizvane.members.facade.utils.EncryptPhone;

import java.io.Serializable;
import java.util.Date;

@EncryptPhone
@EncryptCardNo
public class MbrDistributionRecordPO implements Serializable {
    /**
     * 只读.
    主键id. mbr_distribution_record_id
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "主键id",name = "mbrDistributionRecordId", required = false,example = "")
    private Long mbrDistributionRecordId;

    /**
     * 只读.
    企业id. sys_company_id
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "企业id",name = "sysCompanyId", required = false,example = "")
    private Long sysCompanyId;

    /**
     * 只读.
    品牌id. brand_id
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "品牌id",name = "brandId", required = false,example = "")
    private Long brandId;

    /**
     * 只读.
    分销员手机号(上线). p_phone
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @EncryptPhone
    @io.swagger.annotations.ApiModelProperty(value = "分销员手机号(上线)",name = "pPhone", required = false,example = "")
    private String pPhone;

    /**
     * 只读.
    分销员姓名. p_name
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "分销员姓名",name = "pName", required = false,example = "")
    @EncryptCardNo
    private String pName;

    /**
     * 只读.
    分销员membercode. p_member_code
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "分销员membercode",name = "pMemberCode", required = false,example = "")
    private String pMemberCode;

    /**
     * 只读.
    线下会员手机号. c_phone
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @EncryptPhone
    @io.swagger.annotations.ApiModelProperty(value = "线下会员手机号",name = "cPhone", required = false,example = "")
    private String cPhone;

    /**
     * 只读.
    下线名称. c_name
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "下线名称",name = "cName", required = false,example = "")
    @EncryptCardNo
    private String cName;

    /**
     * 只读.
    下线member_code. c_member_code
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "下线member_code",name = "cMemberCode", required = false,example = "")
    private String cMemberCode;

    /**
     * 只读.
    订单号. order_no
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "订单号",name = "orderNo", required = false,example = "")
    private String orderNo;

    /**
     * 只读.
    订单金额. trade_amount
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "订单金额",name = "tradeAmount", required = false,example = "")
    private Short tradeAmount;

    /**
     * 只读.
    实付金额. commodity_amount
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "实付金额",name = "commodityAmount", required = false,example = "")
    private Short commodityAmount;

    /**
     * 只读.
    佣金. commission
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "佣金",name = "commission", required = false,example = "")
    private Integer commission;

    /**
     * 只读.
    佣金状态 1待结算 2一结算 3退货. commission_status
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "佣金状态 1待结算 2一结算 3退货",name = "commissionStatus", required = false,example = "")
    private Integer commissionStatus;

    /**
     * 只读.
    消费日期. consume_date
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "消费日期",name = "consumeDate", required = false,example = "")
    private Date consumeDate;

    /**
     * 只读.
    结算日期. deal_date
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "结算日期",name = "dealDate", required = false,example = "")
    private Date dealDate;

    /**
     * 只读.
    佣金规则. regx
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "佣金规则",name = "regx", required = false,example = "")
    private String regx;

    /**
     * 只读.
    数据有效性 1有效 0无效. valid
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "数据有效性 1有效 0无效",name = "valid", required = false,example = "")
    private Boolean valid;

    /**
     * 只读.
    备注. remark
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "备注",name = "remark", required = false,example = "")
    private String remark;

    /**
     * 只读.
    创建人id. create_user_id
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "创建人id",name = "createUserId", required = false,example = "")
    private Long createUserId;

    /**
     * 只读.
    创建人. create_user_name
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "创建人",name = "createUserName", required = false,example = "")
    private String createUserName;

    /**
     * 只读.
    创建日期. create_date
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "创建日期",name = "createDate", required = false,example = "")
    private Date createDate;

    /**
     * 只读.
    修改人id. modified_user_id
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "修改人id",name = "modifiedUserId", required = false,example = "")
    private Long modifiedUserId;

    /**
     * 只读.
    修改人. modified_user_name
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "修改人",name = "modifiedUserName", required = false,example = "")
    private String modifiedUserName;

    /**
     * 只读.
    修改日期. modified_date
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "修改日期",name = "modifiedDate", required = false,example = "")
    private Date modifiedDate;

    /**
     * 只读.
    版本号. version
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    @io.swagger.annotations.ApiModelProperty(value = "版本号",name = "version", required = false,example = "")
    private Integer version;

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    private static final long serialVersionUID = 1L;

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Long getMbrDistributionRecordId() {
        return mbrDistributionRecordId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setMbrDistributionRecordId(Long mbrDistributionRecordId) {
        this.mbrDistributionRecordId = mbrDistributionRecordId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Long getBrandId() {
        return brandId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public String getpPhone() {
        return pPhone;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setpPhone(String pPhone) {
        this.pPhone = pPhone == null ? null : pPhone.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public String getpName() {
        return pName;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setpName(String pName) {
        this.pName = pName == null ? null : pName.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public String getpMemberCode() {
        return pMemberCode;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setpMemberCode(String pMemberCode) {
        this.pMemberCode = pMemberCode == null ? null : pMemberCode.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public String getcPhone() {
        return cPhone;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setcPhone(String cPhone) {
        this.cPhone = cPhone == null ? null : cPhone.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public String getcName() {
        return cName;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setcName(String cName) {
        this.cName = cName == null ? null : cName.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public String getcMemberCode() {
        return cMemberCode;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setcMemberCode(String cMemberCode) {
        this.cMemberCode = cMemberCode == null ? null : cMemberCode.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public String getOrderNo() {
        return orderNo;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setOrderNo(String orderNo) {
        this.orderNo = orderNo == null ? null : orderNo.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Short getTradeAmount() {
        return tradeAmount;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setTradeAmount(Short tradeAmount) {
        this.tradeAmount = tradeAmount;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Short getCommodityAmount() {
        return commodityAmount;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setCommodityAmount(Short commodityAmount) {
        this.commodityAmount = commodityAmount;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Integer getCommission() {
        return commission;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setCommission(Integer commission) {
        this.commission = commission;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Integer getCommissionStatus() {
        return commissionStatus;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setCommissionStatus(Integer commissionStatus) {
        this.commissionStatus = commissionStatus;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Date getConsumeDate() {
        return consumeDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setConsumeDate(Date consumeDate) {
        this.consumeDate = consumeDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Date getDealDate() {
        return dealDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setDealDate(Date dealDate) {
        this.dealDate = dealDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public String getRegx() {
        return regx;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setRegx(String regx) {
        this.regx = regx == null ? null : regx.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Boolean getValid() {
        return valid;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setValid(Boolean valid) {
        this.valid = valid;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setRemark(String remark) {
        this.remark = remark == null ? null : remark.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Long getCreateUserId() {
        return createUserId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public String getCreateUserName() {
        return createUserName;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName == null ? null : createUserName.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Date getCreateDate() {
        return createDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public String getModifiedUserName() {
        return modifiedUserName;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Date getModifiedDate() {
        return modifiedDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public Integer getVersion() {
        return version;
    }

    /**
     * 只读. 
     *
     * @mbg.generated 2019-08-07 10:10:20
     */
    public void setVersion(Integer version) {
        this.version = version;
    }
}
